@@ -4,7 +4,7 @@ import typing as t
 
 
 def _bitbucket_pipelines_url() -> str:
-    return "https://bitbucket.org/atlassianlabs/atlascode/raw/main/resources/schemas/pipelines-schema.json"  # noqa: E501
+    return "https://bitbucket.org/atlassianlabs/intellij-bitbucket-references-plugin/raw/master/src/main/resources/schemas/bitbucket-pipelines.schema.json"  # noqa: E501
 
 
 def _githubusercontent_url(owner: str, repo: str, ref: str, path: str) -> str:
@@ -74,8 +74,12 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
         "url": "https://json.schemastore.org/cloudbuild.json",
         "hook_config": {
             "name": "Validate Google Cloud Build config",
-            "files": r"^cloudbuild\.(yml|yaml)$",
-            "types": "yaml",
+            "description": (
+                "Validate Google Cloud Build config against the schema provided "
+                "by SchemaStore"
+            ),
+            "files": r"^cloudbuild\.(yml|yaml|json)$",
+            "types_or": ["json", "yaml"],
         },
     },
     "dependabot": {
